Calculates the "T0" value (the split corresponding to the maximum value of T^2) for a given list of data sets corresponding to glass fragment features assuming they're appropriate values corresponding to glass fragment features.
find_T0(data, i = 1, j = length(data))A numeric corresponding to the maximum between-sum-of-squares estimate from the sample.
list of glass fragment chemical (or otherwise) features.
Starting element (default = 1)
Ending element (default = length(array))