Learn R Programming

SK4FGA (version 0.1.1)

find_T2: Calculate Hotelling's T^2 Statistic for two independent multivariate samples.

Description

Calculate Hotelling's T^2 Statistic for two independent multivariate samples.

Usage

find_T2(d1, d2)

Value

T^2 value for the two objects.

Arguments

d1

matrix or data.frame type object containing the multivariate data for the first sample.

d2

matrix or data.frame type object containing the multivariate data for the second sample.