Learn R Programming

SK4FGA (version 0.1.1)

generate_indices: Generate a test array of Glass-Fragment Refractive Indices.

Description

Returns a vector of randomly generated refractive indices from a expected normal distribution of glass fragments.

Usage

generate_indices(n = 10, .sd_multi = 1)

Value

A vector of randomly generated RIs.

Arguments

n

Number of refractive indices to generate.

.sd_multi

Scale factor of the standard deviation. Greater values imply more variance in the random sample.

Examples

Run this code

test_ris = generate_indices(8)
partition(test_ris)

test_ris_varied = generate_indices(.sd_multi = 5)
partition(test_ris_varied)

Run the code above in your browser using DataLab