Glass composition data for seven elements from 200 glass items.
data(glass)a `data.frame` with 2400 rows and 9 columns.
factor
factor
numeric
numeric
numeric
numeric
numeric
numeric
numeric
These data are from Grzegorz (Greg) Zadora at the [Institute of Forensic Research](http://ies.krakow.pl/) in Krakow, Poland. They are the log of the ratios of each element to oxygen, so logNaO is the log(10) of the Sodium to Oxygen ratio, and logAlO is the log of the Aluminium to Oxygen ratio. The instrumental method was SEM-EDX.
The `item` indicates the object the glass came from. The levels for each item are unique to that item. The `fragment` can be considered a sub-item. When collecting these observations Greg took a glass object, say a jam jar, he would then break it, and extract four fragments. Each fragment would be measured three times upon different parts of that fragment. The fragment labels are repeated, so, for example, fragment "f1" from item "s2" has nothing whatsoever to do with fragment "f1" from item "s101".
For two level models use `item` as the lower level - three level models can use the additional information from the individual fragments.
Aitken, C.G.G. Zadora, G. & Lucy, D. (2007) A Two-Level Model for Evidence Evaluation. Journal of Forensic Sciences: 52(2); 412-419.