Learn R Programming

SK4FGA (version 0.1.1)

partition: Create Partitions of an RI array.

Description

Partitions the array of assumed glass fragment refractive indices into statistically significant groups.

Usage

partition(array, alpha = 0.05, .debug = FALSE)

Value

sk_partition_tree

Arguments

array

Vector of refractive indices.

alpha

Significance parameter "[0,1]". Higher values are more likely to partition the array further.

.debug

Runs debugging.

Examples

Run this code

set.seed(123)
ris = generate_indices(8, 4)
part = partition(ris)
plot(part)
part$groups


Run the code above in your browser using DataLab