powered by
Calculate Hotelling's T^2 Statistic for two independent multivariate samples.
find_T2(d1, d2)
T^2 value for the two objects.
matrix or data.frame type object containing the multivariate data for the first sample.
matrix or data.frame type object containing the multivariate data for the second sample.