powered by
Partitions the array of assumed glass fragment refractive indices into statistically significant groups.
partition(array, alpha = 0.05, .debug = FALSE)
sk_partition_tree
Vector of refractive indices.
Significance parameter "[0,1]". Higher values are more likely to partition the array further.
Runs debugging.
set.seed(123) ris = generate_indices(8, 4) part = partition(ris) plot(part) part$groups
Run the code above in your browser using DataLab